@@ -40,6 +40,7 @@ class AWSProvider(Provider):
 
     def __init__(self):
         """Object initialization."""
+        super().__init__()
         self._name = PROVISIONER_KEY
         self.dsp_name = "AWS"
         self.ssh_key = None
@@ -244,7 +245,8 @@ class AWSProvider(Provider):
         # For all hosts, get subnets in dict (with no repetitions) and list of
         # provided single & multiple subnets
         for host in hosts:
-            if subnet_ids := host.get("subnet_ids"):
+            subnet_ids = host.get("subnet_ids")
+            if subnet_ids:
                 if len(subnet_ids) == 1:
                     single_subnet_prov.append(subnet_ids[0])
                     if subnet_ids[0] not in ip_availabilities:
@@ -296,6 +298,26 @@ class AWSProvider(Provider):
 
         return True
 
+    async def utilization(self):
+        """Check percentage utilization of given provider."""
+        net_sizes = {
+            "28": 14,
+            "27": 30,
+            "26": 62,
+            "25": 126,
+            "24": 254,
+            "23": 510,
+        }
+        res = 0
+        for net, _availability in self.subnets_capacity.items():
+            subnet = self.ec2.Subnet(net)
+            size = net_sizes[subnet.cidr_block.split("/")[-1]]
+            self.subnets_capacity[net] = subnet.available_ip_address_count
+            usage = (size - self.subnets_capacity[net]) / size * 100
+            res = usage if usage > res else res
+
+        return res
+
     async def create_server(self, req):
         """Issue creation of a server.
 
@@ -353,7 +375,8 @@ class AWSProvider(Provider):
             "TagSpecifications": [{"ResourceType": "instance", "Tags": taglist}],
         }
 
-        if subnet_ids := specs.get("subnet_ids"):
+        subnet_ids = specs.get("subnet_ids")
+        if subnet_ids:
             shuffle(subnet_ids)  # Randomize subnets order
             for subnet_id in subnet_ids:
                 if self.subnets_capacity[subnet_id] > 0:
