@@ -580,7 +580,7 @@ class OpenStackProvider(Provider):
 
         if not flavor:
             specs = f"flavor: {flavor_spec}, ref: {flavor_ref}"
-            raise ValidationError(f"Flavor not found: {specs}")
+            raise ValidationError(f"Flavor not found: {specs}", self.dsp_name)
         return flavor
 
     def _translate_image(self, req):
@@ -593,7 +593,7 @@ class OpenStackProvider(Provider):
             image = self._get_image(image_spec, image_spec)
         if not image:
             specs = f"image: {image_spec}, ref: {image_ref}"
-            raise ValidationError(f"Image not found {specs}")
+            raise ValidationError(f"Image not found {specs}", self.dsp_name)
         return image
 
     def _translate_networks(self, req, spec=False):
@@ -607,12 +607,16 @@ class OpenStackProvider(Provider):
             uuid = network_spec.get("uuid")
             network = self._get_network(ref=uuid)
             if not network:
-                raise ValidationError(f"Network not found: {network_spec}")
+                raise ValidationError(
+                    f"Network not found: {network_spec}", self.dsp_name
+                )
             networks.append(network)
         if network_req:
             network = self._get_network(name=network_req, ref=network_req)
             if not network:
-                raise ValidationError(f"Network not found: {network_req}")
+                raise ValidationError(
+                    f"Network not found: {network_req}", self.dsp_name
+                )
 
             network_specs.append({"uuid": network["id"]})
             networks.append(network)
@@ -690,11 +694,23 @@ class OpenStackProvider(Provider):
         except TypeError as flavor_none:
             # func does not load flavor so None is used as result
             raise ValidationError(
-                f"Could not load the flavor for requirement: {req}"
+                f"Could not load the flavor for requirement: {req}", self.dsp_name
             ) from flavor_none
 
         return res
 
+    async def _load_limits(self):
+        limits_await = await self._openstack_gather_responses(self.nova.limits.show())
+        self.limits = limits_await[0]  # gather returns list
+
+        limits = self.limits["limits"]["absolute"]
+        used_vcpus = limits["totalCoresUsed"]
+        used_memory = limits["totalRAMUsed"]
+        limit_vcpus = limits["maxTotalCores"]
+        limit_memory = limits["maxTotalRAMSize"]
+
+        return used_vcpus, used_memory, limit_vcpus, limit_memory
+
     async def can_provision(self, hosts):  # pylint: disable=arguments-differ
         """Check that all host can be provisioned.
 
@@ -712,14 +728,7 @@ class OpenStackProvider(Provider):
 
         # poll the actual openstack load
         logger.debug(f"{self.dsp_name} Loading nova limits")
-        limits_await = await self._openstack_gather_responses(self.nova.limits.show())
-        self.limits = limits_await[0]  # gather returns list
-
-        limits = self.limits["limits"]["absolute"]
-        used_vcpus = limits["totalCoresUsed"]
-        used_memory = limits["totalRAMUsed"]
-        limit_vcpus = limits["maxTotalCores"]
-        limit_memory = limits["maxTotalRAMSize"]
+        used_vcpus, used_memory, limit_vcpus, limit_memory = self._load_limits()
 
         req_vcpus = used_vcpus + vcpus
         req_memory = used_memory + ram
@@ -738,12 +747,7 @@ class OpenStackProvider(Provider):
 
     async def utilization(self):
         """Check utilization of provider."""
-        limits_await = await self._openstack_gather_responses(self.nova.limits.show())
-        self.limits = limits_await[0]  # gather returns list
-        used_vcpus = self.limits["totalCoresUsed"]
-        used_memory = self.limits["totalRAMUsed"]
-        limit_vcpus = self.limits["maxTotalCores"]
-        limit_memory = self.limits["maxTotalRAMSize"]
+        used_vcpus, used_memory, limit_vcpus, limit_memory = self._load_limits()
         cpu_util = used_vcpus / limit_vcpus * 100
         memory_util = used_memory / limit_memory * 100
         return cpu_util if memory_util <= cpu_util else memory_util
